@@ -23,9 +23,10 @@ namespace ClockPartsDraw {
 
     \brief parent [i] 親ウィジット
   */
-  extern void redraw(QPainter& painter,
+  extern void redraw(QPainter& painter, QRegion& region,
                      const ThemeResource& resource,
                      const QVector<QPoint>& digital_positions,
+                     const QVector<QPoint>& calendar_positions,
                      size_t scaling_percent = 100, int sec_offset = 0);
 };
 
