@@ -17,7 +17,7 @@ struct ClockSettingDialog::pImpl {
   void initializeForm(ClockSettingDialog* parent) {
 
     // アイコンの適用
-    parent->setWindowIcon(QIcon(":icons/qtmclock_config_icon"));
+    parent->setWindowIcon(QIcon(":icons/qtmclock_icon"));
 
     // 拡大率の変更
     connect(parent->scale_slider_, SIGNAL(valueChanged(int)),
