@@ -167,6 +167,32 @@ struct SettingConfig::pImpl {
     tags_.insert("digital/s1_ypos", "0");
     tags_.insert("digital/s2_xpos", "0");
     tags_.insert("digital/s2_ypos", "0");
+
+    // カレンダー画像
+    tags_.insert("calendar/number", "days");
+    tags_.insert("calendar/separator", "separator");
+    tags_.insert("calendar/week", "week");
+    tags_.insert("calendar/month", "on");
+
+    tags_.insert("calendar/m1_xpos", "0");
+    tags_.insert("calendar/m1_ypos", "0");
+    tags_.insert("calendar/m2_xpos", "0");
+    tags_.insert("calendar/m2_ypos", "0");
+    tags_.insert("calendar/d1_xpos", "0");
+    tags_.insert("calendar/d1_ypos", "0");
+    tags_.insert("calendar/d2_xpos", "0");
+    tags_.insert("calendar/d2_ypos", "0");
+    tags_.insert("calendar/we_xpos", "0");
+    tags_.insert("calendar/we_ypos", "0");
+    tags_.insert("calendar/s1_xpos", "0");
+    tags_.insert("calendar/s1_ypos", "0");
+    tags_.insert("calendar/s2_xpos", "0");
+    tags_.insert("calendar/s2_ypos", "0");
+
+    // 追加画像
+    tags_.insert("additional/near", "near");
+    tags_.insert("additional/ne_xpos", "0");
+    tags_.insert("additional/ne_ypos", "0");
   }
 
 
@@ -256,6 +282,30 @@ struct SettingConfig::pImpl {
     n = sizeof(digital_tags) / sizeof(digital_tags[0]);
     writeTagValues(fout, "digital", digital_tags, n);
 
+    fout << std::endl;
+
+    // カレンダー情報
+    const char* calendar_tags[] = {
+      "number", "separator", "week",
+      "month",
+      "m1_xpos", "m1_ypos", "m2_xpos", "m2_ypos",
+      "d1_xpos", "d1_ypos", "d2_xpos", "d2_ypos",
+      "we_xpos", "we_ypos",
+      "s1_xpos", "s1_ypos", "s2_xpos", "s2_ypos",
+    };
+    n = sizeof(calendar_tags) / sizeof(calendar_tags[0]);
+    writeTagValues(fout, "calendar", calendar_tags, n);
+
+    fout << std::endl;
+
+    // 追加画像
+    const char* additional_tags[] = {
+      "near",
+      "ne_xpos", "ne_ypos",
+    };
+    n = sizeof(additional_tags) / sizeof(additional_tags[0]);
+    writeTagValues(fout, "additional", additional_tags, n);
+
     fout << "<lm_tmclock" << std::endl;
 
     return true;
