@@ -6,8 +6,6 @@
 
   $Id$
 
-  \todo 拡大縮小の機能を実装する
-  \todo 月、日、曜日、の表示機能を付加する
   \todo エラーメッセージの処理
   \todo 時刻毎のベース画像切替え機能を実装する
   \todo アニメーション機能を付加する
@@ -39,15 +37,20 @@ struct ThemeClockDraw::pImpl {
   bool theme_loaded_;
   QString theme_file_;
   ThemeResource theme_resource_;
-  QRegion* region_;
+  QRegion region_;
+  QWidget* parent_widget_;
   QVector<QPixmap> digital_pixmap_;
+  QVector<QPixmap> number_pixmap_;
+  QVector<QPixmap> week_pixmap_;
+  QVector<QPixmap> separator_pixmap_;
   QVector<QPoint> digital_positions_;
+  QVector<QPoint> calendar_positions_;
   size_t scaling_percent_;
   int sec_offset_;
 
 
   pImpl(ThemeClockDraw* parent)
-    : message_label_(NULL), theme_loaded_(false), region_(NULL),
+    : message_label_(NULL), theme_loaded_(false), parent_widget_(NULL),
       scaling_percent_(100), sec_offset_(0) {
 
     // テーマファイルのドラッグを促すフォームを作成
@@ -126,19 +129,23 @@ struct ThemeClockDraw::pImpl {
     loadPixmap(resource, "analog/hari_h", tags, rrda_encoder);
     loadPixmap(resource, "analog/hari_m", tags, rrda_encoder);
     loadPixmap(resource, "analog/hari_s", tags, rrda_encoder);
+    loadPixmap(resource, "additional/near", tags, rrda_encoder);
 
-    // アナログ部品の位置を格納
+    // アナログ部品、追加画像の位置を格納
     loadOffset(resource, "analog/hari_h",
                "analog/h_xpos", "analog/h_ypos", tags);
     loadOffset(resource, "analog/hari_m",
                "analog/m_xpos", "analog/m_ypos", tags);
     loadOffset(resource, "analog/hari_s",
                "analog/s_xpos", "analog/s_ypos", tags);
+    loadOffset(resource, "additional/near",
+               "additional/ne_xpos", "additional/ne_ypos", tags);
 
     // 設定の格納
     loadOption(resource, "analog/sec", tags);
     loadOption(resource, "digital/colon", tags);
     loadOption(resource, "digital/sec", tags);
+    loadOption(resource, "calendar/month", tags);
 
     // デジタル文字を、文字毎に格納
     loadDigitalCharacter(resource, tags, rrda_encoder);
@@ -146,6 +153,12 @@ struct ThemeClockDraw::pImpl {
     // デジタル文字の描画位置を設定
     loadDigitalPosition(digital_positions_, tags);
 
+    // カレンダー文字、曜日、セパレータを、文字毎に格納
+    loadCalendarCharacter(resource, tags, rrda_encoder);
+
+    // カレンダー文字の描画位置を設定
+    loadCalendarPosition(calendar_positions_, tags);
+
     // 描画リソースが何もなければ、エラー
     if (resource.pixmap.empty()) {
       return false;
@@ -225,43 +238,110 @@ struct ThemeClockDraw::pImpl {
                             QMap<std::string, std::string>& tags,
                             RrdaEncoder& rrda_encoder) {
 
-    ThemeResource digital_resource;
-    if (! loadPixmap(digital_resource, "digital/parts", tags, rrda_encoder)) {
-      return;
-    }
-
-    QPixmap* pixmap = digital_resource.pixmap.value("digital/parts", NULL);
-    if (! pixmap) {
-      // !!! 失敗はしないはずだが、一応
-      return;
-    }
-    const QSize size = pixmap->size();
-
     // 文字毎に等間隔で分割して登録する
     const char* tag_names[] = {
       "0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
       " ", ":", "A", "P",
     };
     size_t n = sizeof(tag_names) / sizeof(tag_names[0]);
-    digital_pixmap_.clear();
-    for (size_t i = 0; i < n; ++i) {
+
+    loadCharacterImages(resource, tags, rrda_encoder,
+                        digital_pixmap_, "digital/parts", tag_names, n);
+  }
+
+
+  // カレンダー用画像の読み出し
+  bool loadCalendarCharacter(ThemeResource& resource,
+                             QMap<std::string, std::string>& tags,
+                             RrdaEncoder& rrda_encoder) {
+
+    // 数値文字の読み出し
+    const char* number_names[] = {
+      "C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9",
+    };
+    size_t n = sizeof(number_names) / sizeof(number_names[0]);
+
+    if (! loadCharacterImages(resource, tags, rrda_encoder, number_pixmap_,
+                              "calendar/number", number_names, n)) {
+      return false;
+    }
+
+    // 曜日の読み出し
+    const char* week_names[] = {
+      "SUN", "MON", "TUE", "WED", "THU", "FRI", "SAT",
+    };
+    n = sizeof(week_names) / sizeof(week_names[0]);
+
+    if (! loadCharacterImages(resource, tags, rrda_encoder,
+                              week_pixmap_, "calendar/week", week_names, n)) {
+      return false;
+    }
+
+    // 区切り文字の読み出し
+    const char* separator_names[] = {
+      "MONTH", "DAY",
+    };
+    n = sizeof(separator_names) / sizeof(separator_names[0]);
+
+    if (! loadCharacterImages(resource, tags, rrda_encoder, separator_pixmap_,
+                              "calendar/separator", separator_names, n)) {
+      return false;
+    }
+
+    return true;
+  }
+
+
+  // 文字画像の読み出し
+  bool loadCharacterImages(ThemeResource& resource,
+                           QMap<std::string, std::string>& tags,
+                           RrdaEncoder& rrda_encoder,
+                           QVector<QPixmap>& pixmaps,
+                           const char* image_tag,
+                           const char* tag_names[], size_t tag_names_size) {
+
+    ThemeResource digital_resource;
+    if (! loadPixmap(digital_resource, image_tag, tags, rrda_encoder)) {
+      return false;
+    }
+
+    QPixmap* pixmap = digital_resource.pixmap.value(image_tag, NULL);
+    if (! pixmap) {
+      // !!! 失敗はしないはずだが、一応
+      return false;
+    }
+    const QSize size = pixmap->size();
+
+    // 文字毎に等間隔で分割して登録する
+    pixmaps.clear();
+    size_t each_width = size.width() / tag_names_size;
+    size_t each_height = size.height();
+    for (size_t i = 0; i < tag_names_size; ++i) {
 
       // !!! list にしておけば、アドレスが変化しないので、より適切か？
-      digital_pixmap_.
-        push_back(pixmap->copy(size.width() * i / n,
-                               0, size.width() / n, size.height()));
+      pixmaps.push_back(pixmap->copy(i * each_width, 0,
+                                     each_width, each_height));
     }
 
     // 登録した vector のアドレスを確保
-    for (size_t i = 0; i < n; ++i) {
-      resource.pixmap.insert(tag_names[i], &digital_pixmap_[i]);
+    for (size_t i = 0; i < tag_names_size; ++i) {
+      resource.pixmap.insert(tag_names[i], &pixmaps[i]);
     }
+
+    return true;
   }
 
 
   // フォームの初期化
   void initializeWidget(ThemeClockDraw* parent) {
 
+#if 0
+    // 透明にしてみる
+    //parent->setAutoFillBackground(true);
+    QColor color(0, 0, 0, 0);
+    parent->setPalette(color);
+#endif
+
     resizeWidget(parent);
   }
 
@@ -275,7 +355,6 @@ struct ThemeClockDraw::pImpl {
       QSize(static_cast<int>(scaling_percent_ * size.width() / 100.0),
             static_cast<int>(scaling_percent_ * size.height() / 100.0));
     QPixmap scaled_pixmap = base_pixmap->scaled(scaled_size);
-    region_ = new QRegion(scaled_pixmap.mask());
     parent->resize(scaled_pixmap.size());
   }
 
@@ -285,14 +364,21 @@ struct ThemeClockDraw::pImpl {
 
     // 部品の再描画
     QPainter painter(parent);
-    ClockPartsDraw::redraw(painter, theme_resource_, digital_positions_,
+    region_ = QRegion();
+    ClockPartsDraw::redraw(painter, region_, theme_resource_,
+                           digital_positions_, calendar_positions_,
                            scaling_percent_, sec_offset_);
+    if (parent_widget_) {
+      parent_widget_->setMask(region_);
+    }
+    painter.end();
   }
 
   // テーマのリソースからの読み出し
   bool loadThemeResouce(const QMap<std::string, QPixmap*>& pixmaps,
                         const QMap<std::string, QRect>& offset,
                         const QVector<QPoint>& digital_positions,
+                        const QVector<QPoint>& calendar_positions,
                         const QMap<std::string, std::string>& option) {
 
     // 画像リソースの更新
@@ -301,10 +387,10 @@ struct ThemeClockDraw::pImpl {
     // 位置情報の更新
     theme_resource_.offset = offset;
     digital_positions_ = digital_positions;
-    theme_resource_.option = option;
+    calendar_positions_ = calendar_positions;
 
     // オプション設定の更新
-    // !!!
+    theme_resource_.option = option;
 
     theme_loaded_ = true;
 
@@ -344,10 +430,14 @@ bool ThemeClockDraw::loadThemeResource(const QMap<std::string, QPixmap*>&
                                        const QMap<std::string, QRect>& offset,
                                        const QVector<QPoint>&
                                        digital_positions,
+                                       const QVector<QPoint>&
+                                       calendar_positions,
                                        const QMap<std::string, std::string>&
                                        option) {
 
-  if (! pimpl->loadThemeResouce(pixmaps, offset, digital_positions, option)) {
+  if (! pimpl->loadThemeResouce(pixmaps, offset,
+                                digital_positions, calendar_positions,
+                                option)) {
     return false;
   }
 
@@ -366,9 +456,10 @@ const QString ThemeClockDraw::getThemeFile(void) {
 
 
 // 再描画
-void ThemeClockDraw::redraw(int sec_offset) {
+void ThemeClockDraw::redraw(int sec_offset, QWidget* parent) {
 
   pimpl->sec_offset_ = sec_offset;
+  pimpl->parent_widget_ = parent;
   if (pimpl->theme_loaded_) {
     // 描画イベントを発生させる
     update();
@@ -394,13 +485,6 @@ void ThemeClockDraw::closeEvent(QCloseEvent* event) {
 }
 
 
-// 透過領域の取得
-QRegion* ThemeClockDraw::getRegion(void) {
-
-  return (pimpl->theme_loaded_) ? pimpl->region_ : NULL;
-}
-
-
 // 描画の拡大率を設定
 void ThemeClockDraw::updateScalingPercent(size_t percent) {
 
