@@ -57,6 +57,11 @@ struct ThemeClockWidget::pImpl {
 
     // テーマファイルの Drop を許可
     parent->setAcceptDrops(true);
+
+    // 影響が薄そうな色、ということで灰色にしておき、
+    // アンチエイリアスの効果を期待して、少しだけ透明にしておく
+    QColor color(128, 128, 128, 223);
+    parent->setPalette(color);
   }
 
 
@@ -79,7 +84,7 @@ struct ThemeClockWidget::pImpl {
     }
 
     // 再描画処理
-    draw_widget_->redraw();
+    draw_widget_->redraw(0, parent);
   }
 
 
@@ -217,10 +222,7 @@ void ThemeClockWidget::redraw(void) {
 void ThemeClockWidget::resizeEvent(QResizeEvent* event) {
   static_cast<void>(event);
 
-  QRegion* region = pimpl->draw_widget_->getRegion();
-  if (region) {
-    setMask(*region);
-  }
+  redraw();
 }
 
 
