@@ -40,4 +40,10 @@ extern void loadDigitalPosition(QVector<QPoint>& digital_positions,
 extern void loadDigitalPosition(QVector<QPoint>& digital_positions,
                                 QMap<std::string, QPoint>& parts_positions);
 
+extern void loadCalendarPosition(QVector<QPoint>& calendar_positions,
+                                 const QMap<std::string, std::string>& tags);
+
+extern void loadCalendarPosition(QVector<QPoint>& calendar_positions,
+                                 QMap<std::string, QPoint>& parts_positions);
+
 #endif /* !THEME_RESOURCE_H */
