@@ -54,6 +54,8 @@ static const char* ImageTags[] = {
   "base/base_org",
   "analog/hari_h", "analog/hari_m", "analog/hari_s",
   "digital/parts",
+  "calendar/number", "calendar/week", "calendar/separator",
+  "additional/near",
 };
 
 
@@ -70,6 +72,16 @@ static const position_tag_t PositionTags[] = {
   { "digital/s2", "digital/s2_xpos", "digital/s2_ypos", },
   { "digital/cl", "digital/cl_xpos", "digital/cl_ypos", },
   { "digital/ap", "digital/ap_xpos", "digital/ap_ypos", },
+
+  { "calendar/m1", "calendar/m1_xpos", "calendar/m1_ypos", },
+  { "calendar/m2", "calendar/m2_xpos", "calendar/m2_ypos", },
+  { "calendar/d1", "calendar/d1_xpos", "calendar/d1_ypos", },
+  { "calendar/d2", "calendar/d2_xpos", "calendar/d2_ypos", },
+  { "calendar/we", "calendar/we_xpos", "calendar/we_ypos", },
+  { "calendar/s1", "calendar/s1_xpos", "calendar/s1_ypos", },
+  { "calendar/s2", "calendar/s2_xpos", "calendar/s2_ypos", },
+
+  { "additional/near", "additional/ne_xpos", "additional/ne_ypos", },
 };
 
 
@@ -100,6 +112,9 @@ struct ThemeConfigWindow::pImpl {
   Items items_;
   AdditionalLinesRect additional_lines_rect_;
   std::vector<QPixmap> digital_parts_;
+  std::vector<QPixmap> number_parts_;
+  std::vector<QPixmap> week_parts_;
+  std::vector<QPixmap> separator_parts_;
 
   PositionMap parts_positions_;
 
@@ -135,6 +150,9 @@ struct ThemeConfigWindow::pImpl {
     parent->parts_tree_->header()->setResizeMode(0, QHeaderView::Stretch);
     parent->parts_tree_->header()->setResizeMode(1, QHeaderView::Stretch);
 
+    // タブの初期選択
+    parent->checkbox_tab_->setCurrentIndex(0);
+
     // チェックボックス
     connect(parent->center_checkbox_, SIGNAL(clicked(bool)),
             parent, SLOT(centerCheckHandler(bool)));
@@ -145,6 +163,8 @@ struct ThemeConfigWindow::pImpl {
     connect(parent->digital_checkbox_, SIGNAL(clicked(bool)),
             parent, SLOT(digitalCheckHandler(bool)));
     same_hands_center_ = parent->center_checkbox_->isChecked();
+    connect(parent->month_checkbox_, SIGNAL(clicked(bool)),
+            parent, SLOT(monthCheckHandler(bool)));
 
     // メニューイベントの接続
     connect(parent->action_exit_, SIGNAL(triggered()), parent, SLOT(close()));
@@ -257,6 +277,54 @@ struct ThemeConfigWindow::pImpl {
     // am/mp
     QTreeWidgetItem* ap = digital->child(4);
     registerTreeItem("digital/ap", ap);
+
+    // カレンダー
+    QTreeWidgetItem* calendar = parent->parts_tree_->itemBelow(digital);
+    registerTreeItem("calendar/parts", calendar);
+
+    // カレンダー用の文字画像
+    QTreeWidgetItem* number = calendar->child(0);
+    registerTreeItem("calendar/number", number);
+
+    QTreeWidgetItem* separator = calendar->child(1);
+    registerTreeItem("calendar/separator", separator);
+
+    // m1
+    QTreeWidgetItem* calendar_m1 = number->child(0);
+    registerTreeItem("calendar/m1", calendar_m1);
+
+    // m2
+    QTreeWidgetItem* calendar_m2 = calendar_m1->child(0);
+    registerTreeItem("calendar/m2", calendar_m2);
+
+    // s1
+    QTreeWidgetItem* calendar_s1 = calendar_m1->child(1);
+    registerTreeItem("calendar/s1", calendar_s1);
+
+    // d1
+    QTreeWidgetItem* calendar_d1 = number->child(1);
+    registerTreeItem("calendar/d1", calendar_d1);
+
+    // d2
+    QTreeWidgetItem* calendar_d2 = calendar_d1->child(0);
+    registerTreeItem("calendar/d2", calendar_d2);
+
+    // s2
+    QTreeWidgetItem* calendar_s2 = calendar_d1->child(1);
+    registerTreeItem("calendar/s2", calendar_s2);
+
+    // 曜日
+    QTreeWidgetItem* week = calendar->child(2);
+    registerTreeItem("calendar/week", week);
+
+    // 追加画像
+    QTreeWidgetItem* additional = parent->parts_tree_->itemBelow(calendar);
+    registerTreeItem("additional", additional);
+
+    // 手前
+    QTreeWidgetItem* near = additional->child(0);
+    registerTreeItem("additional/near", near);
+
   }
 
 
@@ -268,12 +336,19 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
-  // アナログ部品のノードを開く
-  void expandAnalogNode(ThemeConfigWindow* parent) {
+  // 部品のノードを開く
+  void expandSubTreeNode(ThemeConfigWindow* parent) {
 
     QTreeWidgetItem* base = parent->parts_tree_->itemAt(0, 0);
     QTreeWidgetItem* analog = parent->parts_tree_->itemBelow(base);
     parent->parts_tree_->expandItem(analog);
+
+#if 0
+    // !!! 動作しない理由は不明
+    QTreeWidgetItem* digital = parent->parts_tree_->itemBelow(analog);
+    QTreeWidgetItem* calendar = parent->parts_tree_->itemBelow(digital);
+    parent->parts_tree_->expandItem(calendar);
+#endif
   }
 
 
@@ -293,7 +368,8 @@ struct ThemeConfigWindow::pImpl {
     parent->offset_slider_->setEnabled(enable);
 
     // 編集用 Widget
-    parent->groupbox_->setEnabled(enable);
+    parent->clock_groupbox_->setEnabled(enable);
+    parent->calendar_groupbox_->setEnabled(enable);
     parent->parts_tree_->setEnabled(enable);
   }
 
@@ -361,11 +437,6 @@ struct ThemeConfigWindow::pImpl {
     // 部品位置の反映
     loadPosition();
 
-    // チェックボックスへの反映
-    // !!! "針の中心をそろえる" は、設定ファイルを作ったときに管理する
-    // !!! または、データの中心が同じならば、チェックを有効にする
-    // !!! 画像サイズがわからないと、確認できないが...
-
     // 秒針の 表示 / 非表示
     bool analog_sec = ! setting_config_->getValue("analog/sec").compare("on");
     parent->analog_checkbox_->setChecked(analog_sec);
@@ -374,6 +445,11 @@ struct ThemeConfigWindow::pImpl {
     bool digital_sec = ! setting_config_->getValue("digital/sec").compare("on");
     parent->digital_checkbox_->setChecked(digital_sec);
 
+    // カレンダー月の 表示 / 非表示
+    bool calendar_month =
+      ! setting_config_->getValue("calendar/month").compare("on");
+    parent->month_checkbox_->setChecked(calendar_month);
+
     // 部品画像のツリーへの設定
     loadImages();
 
@@ -420,10 +496,21 @@ struct ThemeConfigWindow::pImpl {
     const std::string set_name = name.substr(dir_length, std::string::npos);
     name_to_item_[tag]->setText(1, set_name.c_str());
 
-    // デジタル画像の場合、数値部品を更新する
+    // デジタル画像の場合、数値部品を更新
     if (! strcmp(tag, "digital/parts")) {
       updateDigitalParts(*pixmap);
     }
+
+    // カレンダー画像の場合、構成部品を更新
+    if (! strcmp(tag, "calendar/number")) {
+      updateNumberParts(*pixmap);
+
+    } else if (! strcmp(tag, "calendar/separator")) {
+      updateSeparatorParts(*pixmap);
+
+    } else if (! strcmp(tag, "calendar/week")) {
+      updateWeekParts(*pixmap);
+    }
   }
 
   // 数値部品の更新
@@ -435,18 +522,67 @@ struct ThemeConfigWindow::pImpl {
       " ", ":", "A", "P",
     };
 
-    // 部品の更新
-    digital_parts_.clear();
-    QSize size = pixmap.size();
     size_t n = sizeof(tag_names) / sizeof(tag_names[0]);
-    for (size_t i = 0; i < n; ++i) {
-      digital_parts_.push_back(pixmap.copy(size.width() * i / n,
-                                           0, size.width() / n, size.height()));
+    loadCharacterImages(digital_parts_, pixmap, tag_names, n);
+  }
+
+
+  // カレンダー部品(数値)の更新
+  void updateNumberParts(const QPixmap& pixmap) {
+
+    // 数値
+    const char* number_names[] = {
+      "C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9",
+    };
+
+    size_t n = sizeof(number_names) / sizeof(number_names[0]);
+    loadCharacterImages(number_parts_, pixmap, number_names, n);
+  }
+
+
+  // カレンダー部品(週)の更新
+  void updateWeekParts(const QPixmap& pixmap) {
+
+    // 曜日
+    const char* week_names[] = {
+      "SUN", "MON", "TUE", "WED", "THU", "FRI", "SAT",
+    };
+
+    size_t n = sizeof(week_names) / sizeof(week_names[0]);
+    loadCharacterImages(week_parts_, pixmap, week_names, n);
+  }
+
+
+  // カレンダー部品(セパレータ)の更新
+  void updateSeparatorParts(const QPixmap& pixmap) {
+
+    // セパレータ
+    const char* separator_names[] = {
+      "MONTH", "DAY",
+    };
+
+    size_t n = sizeof(separator_names) / sizeof(separator_names[0]);
+    loadCharacterImages(separator_parts_, pixmap, separator_names, n);
+  }
+
+
+  // 部分画像の読み出し
+  void loadCharacterImages(std::vector<QPixmap>& pixmap_parts,
+                           const QPixmap& pixmap, const char* tag_names[],
+                           size_t tag_names_size) {
+    // 部品の更新
+    pixmap_parts.clear();
+    QSize size = pixmap.size();
+    size_t each_width = size.width() / tag_names_size;
+    size_t each_height = size.height();
+    for (size_t i = 0; i < tag_names_size; ++i) {
+      pixmap_parts.push_back(pixmap.copy(each_width * i, 0,
+                                         each_width, each_height));
     }
 
     // 登録した vector のアドレスを確保
-    for (size_t i = 0; i < n; ++i) {
-      pixmaps_.insert(tag_names[i], &digital_parts_[i]);
+    for (size_t i = 0; i < tag_names_size; ++i) {
+      pixmaps_.insert(tag_names[i], &pixmap_parts[i]);
     }
   }
 
@@ -464,6 +600,11 @@ struct ThemeConfigWindow::pImpl {
       updateDefaultDigitalPosition();
     }
 
+    // カレンダー部品の位置が全て (0, 0) のときに、デフォルトの配置を行う
+    if (isCalendarZeroPosition()) {
+      updateDefaultCalendarPosition();
+    }
+
     // 全アイテムの除去
     scene_->clear();
     items_.clear();
@@ -472,6 +613,15 @@ struct ThemeConfigWindow::pImpl {
     QGraphicsItem* parent = NULL;
     parent = registerItem(parent, "base/base_org");
 
+    // カレンダー部品
+    registerItem(parent, "calendar/m1", "C0");
+    registerItem(parent, "calendar/m2", "C1");
+    registerItem(parent, "calendar/d1", "C2");
+    registerItem(parent, "calendar/d2", "C3");
+    registerItem(parent, "calendar/we", "MON");
+    registerItem(parent, "calendar/s1", "MONTH");
+    registerItem(parent, "calendar/s2", "DAY");
+
     // デジタル部品
     registerItem(parent, "digital/h1", "0");
     registerItem(parent, "digital/h2", "1");
@@ -498,6 +648,9 @@ struct ThemeConfigWindow::pImpl {
       registerItem(parent, "analog/hari_s");
     }
 
+    // 追加部品
+    registerItem(parent, "additional/near");
+
     // 補助線
     QPen rect_pen;
     rect_pen.setStyle(Qt::DashLine);
@@ -593,6 +746,7 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
+  // デジタル文字の初期位置を設定
   void updateDefaultDigitalPosition(void) {
 
     QPixmap* pixmap = pixmaps_.value("0", NULL);
@@ -607,11 +761,58 @@ struct ThemeConfigWindow::pImpl {
     parts_positions_["digital/cl"] = QPoint(width * 3, 0);
     parts_positions_["digital/m1"] = QPoint(width * 4, 0);
     parts_positions_["digital/m2"] = QPoint(width * 5, 0);
+
     parts_positions_["digital/s1"] = QPoint(width * 7, 0);
     parts_positions_["digital/s2"] = QPoint(width * 8, 0);
   }
 
 
+  // カレンダー部品の位置が、全て同じかを調べる
+  bool isCalendarZeroPosition(void) {
+
+    const char* calendar_tags[] = {
+      "calendar/m1", "calendar/m2",
+      "calendar/d1", "calendar/d2",
+      "calendar/s1", "calendar/s2",
+      "calendar/we",
+    };
+    size_t n = sizeof(calendar_tags) / sizeof(calendar_tags[0]);
+    for (size_t i = 0; i < n; ++i) {
+
+      PositionMap::iterator p = parts_positions_.find(calendar_tags[i]);
+      if (p == parts_positions_.end()) {
+        // タグがなければ、戻る
+        return false;
+      }
+
+      QPointF position = parts_positions_[calendar_tags[i]];
+      if ((fabs(position.x()) > 0.1) || (fabs(position.y()) > 0.1)) {
+        return false;
+      }
+    }
+    return true;
+  }
+
+
+  // カレンダー文字の初期位置を設定
+  void updateDefaultCalendarPosition(void) {
+
+    QPixmap* pixmap = pixmaps_.value("C0", NULL);
+    if (! pixmap) {
+      return;
+    }
+    size_t width = pixmap->size().width();
+
+    parts_positions_["calendar/m1"] = QPoint(0, 0);
+    parts_positions_["calendar/m2"] = QPoint(width * 1, 0);
+    parts_positions_["calendar/s1"] = QPoint(width * 2, 0);
+    parts_positions_["calendar/d1"] = QPoint(width * 3, 0);
+    parts_positions_["calendar/d2"] = QPoint(width * 4, 0);
+    parts_positions_["calendar/s2"] = QPoint(width * 5, 0);
+    parts_positions_["calendar/we"] = QPoint(width * 6, 0);
+  }
+
+
   // 名前を付けて保存
   void save(ThemeConfigWindow* parent, const std::string& name) {
 
@@ -728,6 +929,41 @@ struct ThemeConfigWindow::pImpl {
       return;
     }
 
+    // カレンダー部品をまとめて操作させる
+    if (! tag.compare("calendar/parts")) {
+      updatePosition(parent, x, y, "calendar/m1");
+      updatePosition(parent, x, y, "calendar/d1");
+      updatePosition(parent, x, y, "calendar/we");
+    }
+
+    // 曜日を移動させるための調整
+    // !!! 原因を理解したら、修正すべき
+    if (! tag.compare("calendar/week")) {
+      updatePosition(parent, x, y, "calendar/we");
+    }
+
+    // "calendar/X1" タグのときは、"digital/X2", セパレータも移動させる
+    if (! tag.compare("calendar/m1")) {
+      updatePosition(parent, x, y, "calendar/m2");
+      updatePosition(parent, x, y, "calendar/s1");
+
+    } else if (! tag.compare("calendar/d1")) {
+      updatePosition(parent, x, y, "calendar/d2");
+      updatePosition(parent, x, y, "calendar/s2");
+    }
+
+    // "calendar/number" タグのときは、"calendar/mX", "calendar/dX" も移動させる
+    if (! tag.compare("calendar/number")) {
+      updatePosition(parent, x, y, "calendar/m1");
+      updatePosition(parent, x, y, "calendar/d1");
+    }
+
+    // "calendar/separator" タグのときは、"calendar/s1", "calendar/s2" も移動させる
+    if (! tag.compare("calendar/separator")) {
+      updatePosition(parent, x, y, "calendar/s1");
+      updatePosition(parent, x, y, "calendar/s2");
+    }
+
     // アナログ部品をまとめて操作させる
     if (! tag.compare("analog")) {
       bool pre_flag = same_hands_center_;
@@ -831,11 +1067,15 @@ struct ThemeConfigWindow::pImpl {
     QVector<QPoint> digital_positions;
     loadDigitalPosition(digital_positions, parts_positions_);
 
+    QVector<QPoint> calendar_positions;
+    loadCalendarPosition(calendar_positions, parts_positions_);
+
     // オフセット位置の生成
     QMap<std::string, QRect> offset;
     setOffset(offset, "analog/hari_h");
     setOffset(offset, "analog/hari_m");
     setOffset(offset, "analog/hari_s");
+    setOffset(offset, "additional/near");
 
     // オプションタグの登録
     QMap<std::string, std::string> option;
@@ -845,10 +1085,12 @@ struct ThemeConfigWindow::pImpl {
                   parent->digital_checkbox_->isChecked() ? "on" : "off");
     option.insert("digital/colon",
                   parent->blink_checkbox_->isChecked() ? "on" : "off");
+    option.insert("calendar/month",
+                  parent->month_checkbox_->isChecked() ? "on" : "off");
 
-    preview_draw_.loadThemeResource(pixmaps_,
-                                    offset ,digital_positions, option);
-
+    preview_draw_.loadThemeResource(pixmaps_, offset ,
+                                    digital_positions, calendar_positions,
+                                    option);
     setPreviewEnabled(parent, true);
 
     // ダイアログの表示
@@ -908,24 +1150,53 @@ struct ThemeConfigWindow::pImpl {
       drawAdditionalLine("analog/hari_h");
       drawAdditionalLine("analog/hari_m");
       drawAdditionalLine("analog/hari_s");
-    }
-    if (! selected_tag.compare("digital/parts")) {
+
+    } else if (! selected_tag.compare("digital/parts")) {
       drawAdditionalLine("digital/h1");
       drawAdditionalLine("digital/m1");
       drawAdditionalLine("digital/s1");
       drawAdditionalLine("digital/cl");
       drawAdditionalLine("digital/ap");
-    }
-    if (! selected_tag.compare("digital/h1")) {
+
+    } else if (! selected_tag.compare("digital/h1")) {
       drawAdditionalLine("digital/h2");
-    }
-    if (! selected_tag.compare("digital/m1")) {
+
+    } else if (! selected_tag.compare("digital/m1")) {
       drawAdditionalLine("digital/m2");
-    }
-    if (! selected_tag.compare("digital/s1")) {
+
+    } else if (! selected_tag.compare("digital/s1")) {
       drawAdditionalLine("digital/s2");
+
+    } else if (! selected_tag.compare("calendar/parts")) {
+      drawAdditionalLine("calendar/number");
+      drawAdditionalLine("calendar/we");
+
+    } else if (! selected_tag.compare("calendar/number")) {
+      drawAdditionalLine("calendar/m1");
+      drawAdditionalLine("calendar/d1");
+      drawAdditionalLine("calendar/s1");
+      drawAdditionalLine("calendar/s2");
+
+    } else if (! selected_tag.compare("calendar/separator")) {
+      drawAdditionalLine("calendar/s1");
+      drawAdditionalLine("calendar/s2");
+
+    } else if (! selected_tag.compare("calendar/m1")) {
+      drawAdditionalLine("calendar/m2");
+      drawAdditionalLine("calendar/s1");
+
+    } else if (! selected_tag.compare("calendar/d1")) {
+      drawAdditionalLine("calendar/d2");
+      drawAdditionalLine("calendar/s2");
     }
 
+    // 曜日を移動させるための調整
+    // !!! 原因を理解したら、修正すべき
+    if (! selected_tag.compare("calendar/week")) {
+      drawAdditionalLine("calendar/we");
+    }
+
+
     PositionMap::iterator it_position = parts_positions_.find(selected_tag);
     if (it_position == parts_positions_.end()) {
       return;
@@ -935,6 +1206,16 @@ struct ThemeConfigWindow::pImpl {
     QPixmap* pixmap = NULL;
     if (! selected_tag.compare(0, 8, "digital/")) {
       pixmap = pixmaps_["0"];
+
+    } else if (! selected_tag.compare(0, 10, "calendar/s")) {
+      pixmap = pixmaps_["MONTH"];
+
+    } else if (! selected_tag.compare("calendar/we")) {
+      pixmap = pixmaps_["MON"];
+
+    } else if (! selected_tag.compare(0, 9, "calendar/")) {
+      pixmap = pixmaps_["C0"];
+
     } else {
       pixmap = pixmaps_[selected_tag];
     }
@@ -966,6 +1247,17 @@ struct ThemeConfigWindow::pImpl {
     additional_lines_rect_.clear();
     updateItems();
   }
+
+
+  // チェックボックスの変更を反映する
+  void applyCheckChanged(ThemeConfigWindow* parent) {
+
+    setSaveEnabled(parent, true);
+
+    if (redraw_timer_.isActive()) {
+      previewOpened(parent);
+    }
+  }
 };
 
 
@@ -1017,8 +1309,8 @@ ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
     pimpl->setSaveEnabled(this, false);
   }
 
-  // アナログ画像のサブツリーを開く
-  pimpl->expandAnalogNode(this);
+  // サブツリーを開く
+  pimpl->expandSubTreeNode(this);
 }
 
 
@@ -1199,11 +1491,7 @@ void ThemeConfigWindow::centerCheckHandler(bool checked) {
 void ThemeConfigWindow::blinkCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("digital/colon", checked ? "on" : "off");
-  pimpl->setSaveEnabled(this, true);
-
-  if (pimpl->redraw_timer_.isActive()) {
-    pimpl->previewOpened(this);
-  }
+  pimpl->applyCheckChanged(this);
 }
 
 
@@ -1211,12 +1499,7 @@ void ThemeConfigWindow::blinkCheckHandler(bool checked) {
 void ThemeConfigWindow::analogCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("analog/sec", checked ? "on" : "off");
-  pimpl->updateItems();
-  pimpl->setSaveEnabled(this, true);
-
-  if (pimpl->redraw_timer_.isActive()) {
-    pimpl->previewOpened(this);
-  }
+  pimpl->applyCheckChanged(this);
 }
 
 
@@ -1224,12 +1507,15 @@ void ThemeConfigWindow::analogCheckHandler(bool checked) {
 void ThemeConfigWindow::digitalCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("digital/sec", checked ? "on" : "off");
-  pimpl->updateItems();
-  pimpl->setSaveEnabled(this, true);
+  pimpl->applyCheckChanged(this);
+}
 
-  if (pimpl->redraw_timer_.isActive()) {
-    pimpl->previewOpened(this);
-  }
+
+// カレンダーで月を表示するか、の設定
+void ThemeConfigWindow::monthCheckHandler(bool checked) {
+
+  pimpl->setting_config_->setValue("calendar/month", checked ? "on" : "off");
+  pimpl->applyCheckChanged(this);
 }
 
 
