@@ -4,7 +4,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="../qtmclock/ThemeClockDraw.cpp" line="55"/>
+        <location filename="../qtmclock/ThemeClockDraw.cpp" line="60"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -35,112 +35,107 @@
         <translation>Theme Config</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="187"/>
+        <location filename="ThemeConfigWindowForm.ui" line="248"/>
         <source>long hand</source>
         <translation>長針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="164"/>
+        <location filename="ThemeConfigWindowForm.ui" line="225"/>
         <source>base</source>
         <translation>ベース</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="179"/>
+        <location filename="ThemeConfigWindowForm.ui" line="240"/>
         <source>short hand</source>
         <translation>短針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="195"/>
+        <location filename="ThemeConfigWindowForm.ui" line="256"/>
         <source>second hand</source>
         <translation>秒針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="204"/>
+        <location filename="ThemeConfigWindowForm.ui" line="265"/>
         <source>digital character</source>
         <translation>デジタル文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="359"/>
+        <location filename="ThemeConfigWindowForm.ui" line="516"/>
         <source>toolbar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="211"/>
+        <location filename="ThemeConfigWindowForm.ui" line="272"/>
         <source>hour</source>
         <translation>時</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="235"/>
+        <location filename="ThemeConfigWindowForm.ui" line="296"/>
         <source>minute</source>
         <translation>分</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="251"/>
+        <location filename="ThemeConfigWindowForm.ui" line="312"/>
         <source>second</source>
         <translation>秒</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="267"/>
+        <location filename="ThemeConfigWindowForm.ui" line="328"/>
         <source>AM/PM</source>
         <translation>AM/PM</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="227"/>
+        <location filename="ThemeConfigWindowForm.ui" line="288"/>
         <source>colon</source>
         <translation>コロン</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="154"/>
+        <location filename="ThemeConfigWindowForm.ui" line="215"/>
         <source>Node</source>
         <translation>項目</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="159"/>
+        <location filename="ThemeConfigWindowForm.ui" line="220"/>
         <source>Value</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="377"/>
+        <location filename="ThemeConfigWindowForm.ui" line="534"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="849"/>
+        <location filename="ThemeConfigWindow.cpp" line="1254"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="389"/>
+        <location filename="ThemeConfigWindowForm.ui" line="546"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="853"/>
+        <location filename="ThemeConfigWindow.cpp" line="1258"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="401"/>
+        <location filename="ThemeConfigWindowForm.ui" line="558"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="857"/>
+        <location filename="ThemeConfigWindow.cpp" line="1262"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="105"/>
+        <location filename="ThemeConfigWindowForm.ui" line="128"/>
         <source>hands&apos;s center are samve.</source>
         <translation>長針、短針、秒針の中心を揃える.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="96"/>
-        <source>Drawing Options</source>
-        <translation>配置オプション</translation>
-    </message>
-    <message>
-        <location filename="ThemeConfigWindowForm.ui" line="172"/>
+        <location filename="ThemeConfigWindowForm.ui" line="233"/>
         <source>analog parts</source>
         <translation>アナログ部品</translation>
     </message>
@@ -150,159 +145,244 @@
         <translation>再生 / 停止</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="312"/>
+        <location filename="ThemeConfigWindowForm.ui" line="469"/>
         <source>File (&amp;F)</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="325"/>
+        <location filename="ThemeConfigWindowForm.ui" line="482"/>
         <source>Edit (&amp;E)</source>
         <translation>編集 (&amp;E)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="331"/>
+        <location filename="ThemeConfigWindowForm.ui" line="488"/>
         <source>Help (&amp;H)</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="848"/>
+        <location filename="ThemeConfigWindow.cpp" line="1253"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="852"/>
+        <location filename="ThemeConfigWindow.cpp" line="1257"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="856"/>
+        <location filename="ThemeConfigWindow.cpp" line="1261"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="406"/>
+        <location filename="ThemeConfigWindowForm.ui" line="563"/>
         <source>Release (&amp;R)</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="411"/>
+        <location filename="ThemeConfigWindowForm.ui" line="568"/>
         <source>Exit (&amp;Q)</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="414"/>
+        <location filename="ThemeConfigWindowForm.ui" line="571"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="419"/>
+        <location filename="ThemeConfigWindowForm.ui" line="576"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="424"/>
+        <location filename="ThemeConfigWindowForm.ui" line="581"/>
         <source>Preview (&amp;R)</source>
         <translation>プレビュー (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="427"/>
+        <location filename="ThemeConfigWindowForm.ui" line="584"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="432"/>
+        <location filename="ThemeConfigWindowForm.ui" line="589"/>
         <source>About (&amp;A)</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="218"/>
+        <location filename="ThemeConfigWindowForm.ui" line="279"/>
         <source>h2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="242"/>
+        <location filename="ThemeConfigWindowForm.ui" line="303"/>
         <source>m2</source>
-        <translation>位置 (1 の位)</translation>
+        <translation>位置 (100 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="258"/>
+        <location filename="ThemeConfigWindowForm.ui" line="319"/>
         <source>s2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="115"/>
+        <location filename="ThemeConfigWindowForm.ui" line="138"/>
         <source>blink digital colon.</source>
         <translation>デジタル文字のコロン表示を点滅させる.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="135"/>
+        <location filename="ThemeConfigWindowForm.ui" line="158"/>
         <source>show digital second.</source>
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="931"/>
+        <location filename="ThemeConfigWindow.cpp" line="1336"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="973"/>
+        <location filename="ThemeConfigWindow.cpp" line="1378"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="971"/>
+        <location filename="ThemeConfigWindow.cpp" line="1376"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="374"/>
+        <location filename="ThemeConfigWindowForm.ui" line="531"/>
         <source>New (&amp;N)</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="386"/>
+        <location filename="ThemeConfigWindowForm.ui" line="543"/>
         <source>Open (&amp;O)</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="398"/>
+        <location filename="ThemeConfigWindowForm.ui" line="555"/>
         <source>Save (&amp;S)</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="281"/>
+        <location filename="ThemeConfigWindowForm.ui" line="438"/>
         <source>Parts image</source>
         <translation>部品画像の更新</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="291"/>
+        <location filename="ThemeConfigWindowForm.ui" line="448"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="125"/>
+        <location filename="ThemeConfigWindowForm.ui" line="148"/>
         <source>show analog second.</source>
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1179"/>
+        <location filename="ThemeConfigWindow.cpp" line="1583"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1181"/>
+        <location filename="ThemeConfigWindow.cpp" line="1585"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1052"/>
+        <location filename="ThemeConfigWindow.cpp" line="1457"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1056"/>
+        <location filename="ThemeConfigWindow.cpp" line="1461"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="108"/>
+        <source>Clock</source>
+        <translation>時計</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="119"/>
+        <source>Clock Settings</source>
+        <translation>描画設定</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="180"/>
+        <source>Calendar</source>
+        <translation>カレンダー</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="186"/>
+        <source>Calendar Settings</source>
+        <translation>描画設定</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="337"/>
+        <source>calendar</source>
+        <translation>カレンダー</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="351"/>
+        <source>month</source>
+        <translation>月</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="375"/>
+        <source>day</source>
+        <translation>日</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="408"/>
+        <source>day of the week</source>
+        <translation>曜日</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="195"/>
+        <source>show month.</source>
+        <translation>月を表示する.</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="344"/>
+        <source>number</source>
+        <translation>数値</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="366"/>
+        <source>month_separator</source>
+        <translation>区切り文字</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="382"/>
+        <source>c_d2</source>
+        <translation>位置 (1 の位)</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="390"/>
+        <source>day_separator</source>
+        <translation>区切り文字</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="400"/>
+        <source>separator</source>
+        <translation>区切り文字</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="358"/>
+        <source>c_m2</source>
+        <translation>位置 (1 の位)</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="417"/>
+        <source>additional</source>
+        <translation>追加部品</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="424"/>
+        <source>near</source>
+        <translation>手前</translation>
+    </message>
 </context>
 </TS>
